summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/keditscheduledlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/keditscheduledlg.cpp')
-rw-r--r--kmymoney2/dialogs/keditscheduledlg.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/dialogs/keditscheduledlg.cpp b/kmymoney2/dialogs/keditscheduledlg.cpp
index 42fc31e..c6ece41 100644
--- a/kmymoney2/dialogs/keditscheduledlg.cpp
+++ b/kmymoney2/dialogs/keditscheduledlg.cpp
@@ -60,8 +60,8 @@ public:
kMandatoryFieldGroup* m_requiredFields;
};
-KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, TQWidget *tqparent, const char *name) :
- KEditScheduleDlgDecl(tqparent, name, true),
+KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, TQWidget *parent, const char *name) :
+ KEditScheduleDlgDecl(parent, name, true),
d(new Private)
{
d->m_schedule = schedule;
@@ -197,7 +197,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
// create the widgets, place them in the tqparent and load them with data
// setup tab order
d->m_tabOrderWidgets.clear();
KMyMoneyRegister::Action action = KMyMoneyRegister::ActionWithdrawal;
@@ -395,7 +395,7 @@ bool KEditScheduleDlg::focusNextPrevChild(bool next)
w = tqApp->tqfocusWidget();
while(w && d->m_tabOrderWidgets.find(w) == -1) {
- // qDebug("'%s' not in list, use tqparent", w->className());
+ // qDebug("'%s' not in list, use parent", w->className());
w = w->parentWidget();
}
// if(w) qDebug("tab order is at '%s'", w->className());
@@ -197,7 +197,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
- // create the widgets, place them in the tqparent and load them with data
+ // create the widgets, place them in the parent and load them with data
// setup tab order
d->m_tabOrderWidgets.clear();